@@ -16,6 +16,9 @@
  * For more information : contact@centreon.com
  *
  */
+
+#include <google/protobuf/util/message_differencer.h>
+
 #include "common/engine_conf/servicedependency_helper.hh"
 
 #include "com/centreon/exceptions/msg_fmt.hh"
@@ -25,12 +28,17 @@ using com::centreon::exceptions::msg_fmt;
 namespace com::centreon::engine::configuration {
 
 size_t servicedependency_key(const Servicedependency& sd) {
-  return absl::HashOf(sd.dependency_period(), sd.dependency_type(),
-                      sd.hosts().data(0), sd.service_description().data(0),
-                      sd.dependent_hosts().data(0),
-                      sd.dependent_service_description().data(0),
-                      sd.execution_failure_options(), sd.inherits_parent(),
-                      sd.notification_failure_options());
+  return absl::HashOf(
+      sd.dependency_period(), sd.dependency_type(), sd.dependent_hostgroups(),
+      sd.dependent_hosts(), sd.dependent_servicegroups(),
+      sd.dependent_service_description(), sd.execution_failure_options(),
+      sd.hostgroups(), sd.hosts(), sd.inherits_parent(),
+      sd.notification_failure_options(), sd.servicegroups(),
+      sd.service_description());
+}
+
+bool operator==(const Servicedependency& left, const Servicedependency& right) {
+  return ::google::protobuf::util::MessageDifferencer::Equals(left, right);
 }
 
 /**
