@@ -37,7 +37,7 @@ timeperiod_helper::timeperiod_helper(Timeperiod* obj)
                      obj,
                      {},
                      Timeperiod::descriptor()->field_count()) {
-  _init();
+  obj->mutable_obj()->set_register_(true);
 }
 
 /**
@@ -46,8 +46,7 @@ timeperiod_helper::timeperiod_helper(Timeperiod* obj)
  * @param key The key to parse.
  * @param value The value corresponding to the key
  */
-bool timeperiod_helper::hook(std::string_view key,
-                             const std::string_view& value) {
+bool timeperiod_helper::hook(std::string_view key, std::string_view value) {
   Timeperiod* obj = static_cast<Timeperiod*>(mut_obj());
   /* Since we use key to get back the good key value, it is faster to give key
    * by copy to the method. We avoid one key allocation... */
@@ -279,11 +278,6 @@ void timeperiod_helper::check_validity(error_cnt& err) const {
   }
 }
 
-void timeperiod_helper::_init() {
-  Timeperiod* obj = static_cast<Timeperiod*>(mut_obj());
-  obj->mutable_obj()->set_register_(true);
-}
-
 /**
  *  Add other date.
  *
