@@ -1,20 +1,20 @@
 /**
-* Copyright 2022 Centreon
-*
-* Licensed under the Apache License, Version 2.0 (the "License");
-* you may not use this file except in compliance with the License.
-* You may obtain a copy of the License at
-*
-*     http://www.apache.org/licenses/LICENSE-2.0
-*
-* Unless required by applicable law or agreed to in writing, software
-* distributed under the License is distributed on an "AS IS" BASIS,
-* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-* See the License for the specific language governing permissions and
-* limitations under the License.
-*
-* For more information : contact@centreon.com
-*/
+ * Copyright 2022 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ */
 
 #include "com/centreon/connector/perl/policy.hh"
 #include "com/centreon/connector/log.hh"
@@ -57,7 +57,7 @@ void policy::start(const std::string& test_cmd_file) {
  *
  */
 void policy::start_second_timer() {
-  _second_timer.expires_from_now(std::chrono::seconds(1));
+  _second_timer.expires_after(std::chrono::seconds(1));
   _second_timer.async_wait(
       [me = shared_from_this()](const boost::system::error_code& err) {
         if (!err) {
@@ -155,7 +155,7 @@ void policy::on_quit() {
  *
  */
 void policy::start_end_timer(bool final) {
-  _end_timer.expires_from_now(std::chrono::milliseconds(10));
+  _end_timer.expires_after(std::chrono::milliseconds(10));
   _end_timer.async_wait([me = shared_from_this(),
                          final](const boost::system::error_code& err) {
     if (!err) {
