@@ -16,6 +16,7 @@
  * For more information : contact@centreon.com
  */
 
+#include "centreon_agent/agent_service.hh"
 #include "com/centreon/exceptions/msg_fmt.hh"
 
 #include "centreon_agent/agent_impl.hh"
@@ -29,6 +30,7 @@
 #include "open_telemetry.hh"
 
 #include "com/centreon/engine/commands/otel_connector.hh"
+#include "common/crypto/cert_tree.hh"
 #include "otl_fmt.hh"
 #include "otl_server.hh"
 
@@ -44,7 +46,8 @@ open_telemetry::open_telemetry(
     const std::string_view config_file_path,
     const std::shared_ptr<asio::io_context>& io_context,
     const std::shared_ptr<spdlog::logger>& logger)
-    : _config_file_path(config_file_path),
+    : _minute_timer(*io_context),
+      _config_file_path(config_file_path),
       _logger(logger),
       _io_context(io_context),
       _agent_stats(centreon_agent::agent_stat::load(io_context)) {
@@ -56,12 +59,27 @@ open_telemetry::open_telemetry(
  *
  */
 void open_telemetry::_reload() {
+  absl::MutexLock l(&_protect);
   std::unique_ptr<otl_config> new_conf =
       std::make_unique<otl_config>(_config_file_path, *_io_context);
 
   if (new_conf->get_grpc_config()) {
     if (!_conf || !_conf->get_grpc_config() ||
         *new_conf->get_grpc_config() != *_conf->get_grpc_config()) {
+      if (new_conf->get_grpc_config()->is_crypted()) {
+        try {
+          // Works even if the private key is unencrypted
+          _server_ca = std::make_unique<crypto::cert_tree>(
+              new_conf->get_grpc_config()->get_cert(),
+              new_conf->get_grpc_config()->get_key(), "centengine",
+              crypto::cert_tree::load_from_str());
+        } catch (const std::exception& e) {
+          SPDLOG_LOGGER_ERROR(_logger, "fail to load otel grpc server keys:{}",
+                              e.what());
+          throw;
+        }
+      }
+
       this->_create_otl_server(new_conf->get_grpc_config(),
                                new_conf->get_centreon_agent_config());
     }
@@ -75,10 +93,7 @@ void open_telemetry::_reload() {
       _otl_server->update_agent_config(new_conf->get_centreon_agent_config());
     }
   } else {  // only reverse connection
-    std::shared_ptr<otl_server> to_shutdown = std::move(_otl_server);
-    if (to_shutdown) {
-      to_shutdown->shutdown(std::chrono::seconds(10));
-    }
+    _shutdown_otl_server();
   }
 
   if (!new_conf->get_telegraf_conf_server_config()) {
@@ -142,11 +157,65 @@ std::shared_ptr<open_telemetry> open_telemetry::load(
   if (!_instance) {
     _instance =
         std::make_shared<open_telemetry>(config_path, io_context, logger);
+    std::static_pointer_cast<open_telemetry>(_instance)->_start_minute_timer();
     instance()->_reload();
   }
   return instance();
 }
 
+/**
+ * @brief start one minute delayed timer
+ *
+ */
+void open_telemetry::_start_minute_timer() {
+  absl::MutexLock l(&_protect);
+  _minute_timer.expires_after(std::chrono::minutes(1));
+  _minute_timer.async_wait(
+      [me = shared_from_this()](const boost::system::error_code& err) {
+        if (!err) {
+          me->_minute_timer_handler();
+        }
+      });
+}
+
+/**
+ * @brief each minute, we check if we have to reload certificates
+ *
+ */
+void open_telemetry::_minute_timer_handler() {
+  {
+    absl::MutexLock l(&_protect);
+    if (_conf && _conf->get_grpc_config() &&
+        _conf->get_grpc_config()->is_crypted()) {
+      /* to restore once we will survey certificate to finish in another PR
+          don't forget to send new fingerprint to broker, it is not done here
+
+          if (_conf->get_mutable_grpc_config()->reload_certificates()) {
+        SPDLOG_LOGGER_INFO(_logger,
+                           "otl certificates had been updated => restart otl
+                           server
+                           "); _server_ca = std::make_unique<crypto::cert_tree>(
+                           _conf->get_grpc_config()
+                               ->get_cert(),
+                           _conf->get_grpc_config()->get_key(), "centengine",
+                           crypto::cert_tree::load_from_str());
+        _create_otl_server(_conf->get_grpc_config(),
+                           _conf->get_centreon_agent_config());
+      }
+      else*/
+      if (_certificate_ttl.time_since_epoch().count() &&
+          _certificate_ttl < std::chrono::system_clock::now()) {
+        SPDLOG_LOGGER_INFO(_logger,
+                           "otl used certificate end of life => auto renew "
+                           "certificate and restart otl server");
+        _create_otl_server(_conf->get_grpc_config(),
+                           _conf->get_centreon_agent_config());
+      }
+    }
+  }
+  _start_minute_timer();
+}
+
 /**
  * @brief create grpc server which accept otel collector connections
  *
@@ -156,16 +225,58 @@ void open_telemetry::_create_otl_server(
     const grpc_config::pointer& server_conf,
     const centreon_agent::agent_config::pointer& agent_conf) {
   try {
-    std::shared_ptr<otl_server> to_shutdown = std::move(_otl_server);
-    if (to_shutdown) {
-      to_shutdown->shutdown(std::chrono::seconds(10));
+    _shutdown_otl_server();
+    grpc_config::pointer low_ttl_conf;
+    // in case of self signed certificate we create shorter ttl certificate
+    // from configured it
+    if (server_conf->is_crypted() && server_conf->get_ca().empty() &&
+        !server_conf->get_cert().empty() &&
+        crypto::cert_tree::is_self_signed(server_conf->get_cert())) {
+      crypto::name_entries ca_entries =
+          crypto::cert_tree::get_name_fields(_server_ca->get_ca());
+
+      // in order to not have a self signed certificate, we just reuse CN of
+      // ca
+      crypto::name_entries entries;
+      std::copy_if(ca_entries.begin(), ca_entries.end(),
+                   std::back_inserter(entries),
+                   [](const crypto::name_entries::value_type& to_test) {
+                     return to_test.first == NID_commonName;
+                   });
+
+      entries.emplace_back(std::make_pair(
+          NID_description,
+          fmt::format("centengine otel certificate {}", time(nullptr))));
+
+      std::pair<X509*, EVP_PKEY*> cert_key = _server_ca->generate_cert_key_pair(
+          entries, server_conf->get_minute_certificate_ttl());
+      low_ttl_conf = std::make_shared<grpc_config>(*server_conf);
+      low_ttl_conf->set_cert(crypto::cert_tree::cert_to_string(cert_key.first));
+      low_ttl_conf->set_key(crypto::cert_tree::key_to_string(cert_key.second));
+      low_ttl_conf->set_ca(
+          crypto::cert_tree::cert_to_string(_server_ca->get_ca()));
+      X509_free(cert_key.first);
+      EVP_PKEY_free(cert_key.second);
     }
+
     _otl_server = otl_server::load(
-        _io_context, server_conf, agent_conf,
+        _io_context, low_ttl_conf ? low_ttl_conf : server_conf, agent_conf,
         [me = shared_from_this()](const metric_request_ptr& request) {
           me->on_metric(request);
         },
         _logger, _agent_stats);
+
+    if (low_ttl_conf) {
+      _certificate_ttl = std::chrono::system_clock::now() +
+                         std::chrono::minutes(
+                             server_conf->get_minute_certificate_ttl() > 2
+                                 ? server_conf->get_minute_certificate_ttl() - 2
+                                 : server_conf->get_minute_certificate_ttl());
+    } else {
+      _certificate_ttl = {};
+    }
+    SPDLOG_LOGGER_INFO(_logger, "start otel server on {}",
+                       server_conf->get_hostport());
   } catch (const std::exception& e) {
     SPDLOG_LOGGER_ERROR(_logger, "fail to create opentelemetry grpc server: {}",
                         e.what());
@@ -253,11 +364,21 @@ void open_telemetry::unload(const std::shared_ptr<spdlog::logger>& logger) {
  *
  */
 void open_telemetry::_shutdown() {
+  _shutdown_otl_server();
+  _agent_stats->stop_send_timer();
+  _minute_timer.cancel();
+}
+
+/**
+ * @brief shutdown agent incoming connections and agent server
+ *
+ */
+void open_telemetry::_shutdown_otl_server() {
+  centreon_agent::agent_service::shutdown_all_accepted();
   std::shared_ptr<otl_server> to_shutdown = std::move(_otl_server);
   if (to_shutdown) {
     to_shutdown->shutdown(std::chrono::seconds(10));
   }
-  _agent_stats->stop_send_timer();
 }
 
 /**
@@ -288,7 +409,7 @@ open_telemetry::create_extractor(
       }
     }
   };
-  std::lock_guard l(_protect);
+  absl::MutexLock l(&_protect);
   auto exist = _extractors.find(cmdline);
   if (exist != _extractors.end()) {
     std::shared_ptr<com::centreon::engine::commands::otel::host_serv_extractor>
@@ -328,7 +449,7 @@ open_telemetry::create_check_result_builder(const std::string& cmdline) {
 void open_telemetry::on_metric(const metric_request_ptr& metrics) {
   std::vector<otl_data_point> unknown;
   {
-    std::lock_guard l(_protect);
+    absl::MutexLock l(&_protect);
     if (_extractors.empty()) {  // no extractor configured => all unknown
       otl_data_point::extract_data_points(
           metrics, [&unknown](const otl_data_point& data_pt) {
@@ -411,4 +532,33 @@ void open_telemetry::_forward_to_broker(
 
 void open_telemetry::force_check(uint64_t host_id, uint64_t serv_id) {
   centreon_agent::agent_impl_base::force_check(host_id, serv_id);
-}
\ No newline at end of file
+}
+
+open_telemetry::certificate_info
+open_telemetry::get_otel_service_certificate_info() {
+  absl::MutexLock l(&_protect);
+
+  open_telemetry::certificate_info ret;
+
+  if (_conf->get_grpc_config() && _conf->get_grpc_config()->get_ca().empty() &&
+      !_conf->get_grpc_config()->get_cert().empty() &&
+      crypto::cert_tree::is_self_signed(_conf->get_grpc_config()->get_cert())) {
+    X509* cert = common::crypto::cert_tree::load_cert_from_string(
+        _conf->get_grpc_config()->get_cert());
+    crypto::name_entries ca_entries =
+        common::crypto::cert_tree::get_name_fields(cert);
+    auto cn_iter =
+        std::find_if(ca_entries.begin(), ca_entries.end(),
+                     [](const crypto::name_entries::value_type& field) {
+                       return field.first == NID_commonName;
+                     });
+    if (cn_iter != ca_entries.end()) {
+      ret.cn = cn_iter->second;
+    }
+    ret.peremption = common::crypto::cert_tree::get_peremption(cert);
+    ret.sha = common::crypto::cert_tree::cert_sha(cert);
+    X509_free(cert);
+  }
+
+  return ret;
+}
