@@ -36,7 +36,8 @@ check_result::check_result()
       _finish_time{0, 0},
       _early_timeout{false},
       _exited_ok{false},
-      _return_code{0} {}
+      _return_code{0},
+      _current_attempt(0) {}
 
 check_result::check_result(enum check_source object_check_type,
                            notifier* notifier,
@@ -61,7 +62,8 @@ check_result::check_result(enum check_source object_check_type,
       _early_timeout{early_timeout},
       _exited_ok{exited_ok},
       _return_code{return_code},
-      _output{std::move(output)} {}
+      _output{std::move(output)},
+      _current_attempt(0) {}
 
 void check_result::set_object_check_type(enum check_source object_check_type) {
   _object_check_type = object_check_type;
