@@ -566,8 +566,8 @@ com::centreon::engine::host::host_state checker::_execute_sync(host* hst) {
   std::string perfdata_output;
 
   // Parse the output: short and long output, and perf data.
-  parse_check_output(res.output, pl_output, lpl_output, perfdata_output, true,
-                     false);
+  common::parse_check_output(res.output, pl_output, lpl_output, perfdata_output,
+                             true, false);
 
   hst->set_plugin_output(pl_output);
   hst->set_long_plugin_output(lpl_output);
