@@ -41,7 +41,7 @@ command_map commands::command::commands;
  */
 commands::command::command(const std::string& name,
                            const std::string& command_line,
-                           command_listener* listener,
+                           const std::shared_ptr<command_listener>& listener,
                            e_type cmd_type)
     : _type(cmd_type),
       _command_line(command_line),
@@ -50,7 +50,12 @@ commands::command::command(const std::string& name,
   if (_name.empty())
     throw engine_error() << "Could not create a command with an empty name";
   if (_listener) {
-    std::function<void()> f = [this] { _listener = nullptr; };
+    std::function<void()> f = [weak_me = weak_from_this()] {
+      auto me = weak_me.lock();
+      if (me) {
+        me->_listener.reset();
+      }
+    };
     _listener->reg(this, f);
   }
 }
@@ -119,12 +124,17 @@ void commands::command::set_command_line(const std::string& command_line) {
  *  @param[in] listener  The listener who catch events.
  */
 void commands::command::set_listener(
-    commands::command_listener* listener) noexcept {
+    const std::shared_ptr<commands::command_listener>& listener) noexcept {
   if (_listener)
     _listener->unreg(this);
   _listener = listener;
   if (_listener) {
-    std::function<void()> f([this] { _listener = nullptr; });
+    std::function<void()> f = [weak_me = weak_from_this()] {
+      auto me = weak_me.lock();
+      if (me) {
+        me->_listener.reset();
+      }
+    };
     _listener->reg(this, f);
   }
 }
