@@ -82,17 +82,6 @@ void contact::set_addresses(std::vector<std::string>&& addresses) {
   _addresses = std::move(addresses);
 }
 
-#ifdef LEGACY_CONF
-/**
- *  Set addresses.
- *
- *  @param[in] addresses  New addresses.
- */
-void contact::set_addresses(std::vector<std::string> const& addresses) {
-  _addresses = addresses;
-}
-#endif
-
 /**
  *  Return the contact alias
  *
@@ -601,13 +590,6 @@ std::shared_ptr<contact> add_contact(
     obj->set_retain_nonstatus_information(retain_nonstatus_information > 0);
     obj->set_retain_status_information(retain_status_information > 0);
     obj->set_service_notifications_enabled(service_notifications_enabled > 0);
-
-    // Notify event broker.
-    timeval tv(get_broker_timestamp(nullptr));
-    broker_adaptive_contact_data(NEBTYPE_CONTACT_ADD, NEBFLAG_NONE,
-                                 NEBATTR_NONE, obj.get(), CMD_NONE, MODATTR_ALL,
-                                 MODATTR_ALL, MODATTR_ALL, MODATTR_ALL,
-                                 MODATTR_ALL, MODATTR_ALL, &tv);
   } catch (...) {
     obj.reset();
   }
@@ -780,18 +762,6 @@ void contact::set_service_notifications_enabled(bool enabled) {
   _service_notifications_enabled = enabled;
 }
 
-/**
- *  Updates contact status info.
- *
- *  @param aggregated_dump
- *
- */
-void contact::update_status_info(bool aggregated_dump) {
-  /* send data to event broker (non-aggregated dumps only) */
-  if (!aggregated_dump)
-    broker_contact_status(NEBTYPE_CONTACTSTATUS_UPDATE, this);
-}
-
 std::list<std::shared_ptr<commands::command> > const&
 contact::get_host_notification_commands() const {
   return _host_notification_commands;
@@ -846,8 +816,7 @@ bool contact::should_be_notified(notifier::notification_category cat,
                                  notifier::reason_type type,
                                  notifier const& notif) const {
   engine_logger(dbg_functions, basic) << "contact::should_be_notified()";
-  functions_logger->trace("contact::should_be_notified() for contact '{}'",
-                          get_name());
+  functions_logger->trace("contact::should_be_notified()");
   /* Are notifications enabled? */
   switch (notif.get_notifier_type()) {
     case notifier::service_notification: {
