@@ -38,12 +38,6 @@
 #include "com/centreon/engine/globals.hh"
 #include "com/centreon/engine/retention/dump.hh"
 #include "com/centreon/engine/timezone_manager.hh"
-#ifdef LEGACY_CONF
-#include "common/engine_legacy_conf/host.hh"
-#include "common/engine_legacy_conf/hostescalation.hh"
-#include "common/engine_legacy_conf/state.hh"
-#else
-#endif
 
 using namespace com::centreon;
 using namespace com::centreon::engine;
@@ -57,30 +51,14 @@ class HostNotification : public TestEngine {
   void SetUp() override {
     init_config_state();
 
-    events_logger->set_level(spdlog::level::off);
-
     error_cnt err;
     configuration::applier::contact ct_aply;
-#ifdef LEGACY_CONF
-    configuration::contact ctct{new_configuration_contact("admin", true)};
-    ct_aply.add_object(ctct);
-#ifdef LEGACY_CONF
-    ct_aply.expand_objects(*config);
-#else
-    ct_aply.expand_objects(pb_config);
-#endif
-#else
     configuration::Contact ctct{new_pb_configuration_contact("admin", true)};
     ct_aply.add_object(ctct);
     ct_aply.expand_objects(pb_config);
-#endif
     ct_aply.resolve_object(ctct, err);
 
-#ifdef LEGACY_CONF
-    configuration::host hst{new_configuration_host("test_host", "admin")};
-#else
     configuration::Host hst{new_pb_configuration_host("test_host", "admin")};
-#endif
     configuration::applier::host hst_aply;
     hst_aply.add_object(hst);
     hst_aply.resolve_object(hst, err);
@@ -132,11 +110,7 @@ TEST_F(HostNotification, SimpleNormalHostNotificationNotificationsdisabled) {
   /* We are using a local time() function defined in tests/timeperiod/utils.cc.
    * If we call time(), it is not the glibc time() function that will be called.
    */
-#ifdef LEGACY_CONF
-  config->enable_notifications(false);
-#else
   pb_config.set_enable_notifications(false);
-#endif
   set_time(43200);
   std::unique_ptr<engine::timeperiod> tperiod{
       new_timeperiod_with_timeranges("tperiod", "alias")};
@@ -200,11 +174,7 @@ TEST_F(HostNotification, SimpleNormalHostNotificationOutsideTimeperiod) {
 
 TEST_F(HostNotification,
        SimpleNormalHostNotificationForcedWithNotificationDisabled) {
-#ifdef LEGACY_CONF
-  config->enable_notifications(false);
-#else
   pb_config.set_enable_notifications(false);
-#endif
   std::unique_ptr<engine::timeperiod> tperiod{
       new_timeperiod_with_timeranges("tperiod", "alias")};
   set_time(20000);
@@ -585,51 +555,25 @@ TEST_F(HostNotification, CheckFirstNotificationDelay) {
 TEST_F(HostNotification, HostEscalation) {
   error_cnt err;
   configuration::applier::contact ct_aply;
-#ifdef LEGACY_CONF
-  configuration::contact ctct{new_configuration_contact("test_contact", false)};
-#else
   configuration::Contact ctct{
       new_pb_configuration_contact("test_contact", false)};
-#endif
   ct_aply.add_object(ctct);
-#ifdef LEGACY_CONF
-  ct_aply.expand_objects(*config);
-#else
   ct_aply.expand_objects(pb_config);
-#endif
   ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
-#ifdef LEGACY_CONF
-  configuration::contactgroup cg{
-      new_configuration_contactgroup("test_cg", "test_contact")};
-#else
   configuration::Contactgroup cg;
   configuration::contactgroup_helper cg_hlp(&cg);
   fill_pb_configuration_contactgroup(&cg_hlp, "test_cg", "test_contact");
-#endif
   cg_aply.add_object(cg);
-#ifdef LEGACY_CONF
-  cg_aply.expand_objects(*config);
-#else
   cg_aply.expand_objects(pb_config);
-#endif
   cg_aply.resolve_object(cg, err);
 
   configuration::applier::hostescalation he_aply;
-#ifdef LEGACY_CONF
-  configuration::hostescalation he{
-      new_configuration_hostescalation("test_host", "test_cg")};
-#else
   configuration::Hostescalation he{
       new_pb_configuration_hostescalation("test_host", "test_cg")};
-#endif
   he_aply.add_object(he);
-#ifdef LEGACY_CONF
-  he_aply.expand_objects(*config);
-#else
   he_aply.expand_objects(pb_config);
-#endif
   he_aply.resolve_object(he, err);
 
   int now{50000};
@@ -739,61 +683,30 @@ TEST_F(HostNotification, HostEscalation) {
 TEST_F(HostNotification, HostDependency) {
   error_cnt err;
   configuration::applier::contact ct_aply;
-#ifdef LEGACY_CONF
-  configuration::contact ctct{new_configuration_contact("test_contact", false)};
-#else
   configuration::Contact ctct{
       new_pb_configuration_contact("test_contact", false)};
-#endif
   ct_aply.add_object(ctct);
-#ifdef LEGACY_CONF
-  ct_aply.expand_objects(*config);
-#else
   ct_aply.expand_objects(pb_config);
-#endif
   ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
-#ifdef LEGACY_CONF
-  configuration::contactgroup cg{
-      new_configuration_contactgroup("test_cg", "test_contact")};
-#else
   configuration::Contactgroup cg;
   configuration::contactgroup_helper cg_hlp(&cg);
   fill_pb_configuration_contactgroup(&cg_hlp, "test_cg", "test_contact");
-#endif
   cg_aply.add_object(cg);
-#ifdef LEGACY_CONF
-  cg_aply.expand_objects(*config);
-#else
   cg_aply.expand_objects(pb_config);
-#endif
   cg_aply.resolve_object(cg, err);
 
   configuration::applier::host h_aply;
-#ifdef LEGACY_CONF
-  configuration::host h{new_configuration_host("dep_host", "admin", 15)};
-#else
   configuration::Host h{new_pb_configuration_host("dep_host", "admin", 15)};
-#endif
   h_aply.add_object(h);
-#ifdef LEGACY_CONF
-  h_aply.expand_objects(*config);
-#else
   h_aply.expand_objects(pb_config);
-#endif
   h_aply.resolve_object(h, err);
 
   configuration::applier::hostdependency hd_aply;
-#ifdef LEGACY_CONF
-  configuration::hostdependency hd{
-      new_configuration_hostdependency("test_host", "dep_host")};
-  hd_aply.expand_objects(*config);
-#else
   configuration::Hostdependency hd{
       new_pb_configuration_hostdependency("test_host", "dep_host")};
   hd_aply.expand_objects(pb_config);
-#endif
   hd_aply.add_object(hd);
   hd_aply.resolve_object(hd, err);
 
@@ -914,49 +827,25 @@ TEST_F(HostNotification, HostDependency) {
 TEST_F(HostNotification, HostEscalationOneTime) {
   error_cnt err;
   configuration::applier::contact ct_aply;
-#ifdef LEGACY_CONF
-  configuration::contact ctct{new_configuration_contact("test_contact", false)};
-  ct_aply.add_object(ctct);
-  ct_aply.expand_objects(*config);
-#else
   configuration::Contact ctct{
       new_pb_configuration_contact("test_contact", false)};
   ct_aply.add_object(ctct);
   ct_aply.expand_objects(pb_config);
-#endif
   ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
-#ifdef LEGACY_CONF
-  configuration::contactgroup cg{
-      new_configuration_contactgroup("test_cg", "test_contact")};
-#else
   configuration::Contactgroup cg;
   configuration::contactgroup_helper cg_hlp(&cg);
   fill_pb_configuration_contactgroup(&cg_hlp, "test_cg", "test_contact");
-#endif
   cg_aply.add_object(cg);
-#ifdef LEGACY_CONF
-  cg_aply.expand_objects(*config);
-#else
   cg_aply.expand_objects(pb_config);
-#endif
   cg_aply.resolve_object(cg, err);
 
   configuration::applier::hostescalation he_aply;
-#ifdef LEGACY_CONF
-  configuration::hostescalation he{
-      new_configuration_hostescalation("test_host", "test_cg", 1, 0)};
-#else
   configuration::Hostescalation he{
       new_pb_configuration_hostescalation("test_host", "test_cg", 1, 0)};
-#endif
   he_aply.add_object(he);
-#ifdef LEGACY_CONF
-  he_aply.expand_objects(*config);
-#else
   he_aply.expand_objects(pb_config);
-#endif
   he_aply.resolve_object(he, err);
 
   int now{50000};
@@ -1036,51 +925,25 @@ TEST_F(HostNotification, HostEscalationOneTime) {
 TEST_F(HostNotification, HostEscalationOneTimeNotifInter0) {
   error_cnt err;
   configuration::applier::contact ct_aply;
-#ifdef LEGACY_CONF
-  configuration::contact ctct{new_configuration_contact("test_contact", false)};
-#else
   configuration::Contact ctct{
       new_pb_configuration_contact("test_contact", false)};
-#endif
   ct_aply.add_object(ctct);
-#ifdef LEGACY_CONF
-  ct_aply.expand_objects(*config);
-#else
   ct_aply.expand_objects(pb_config);
-#endif
   ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
-#ifdef LEGACY_CONF
-  configuration::contactgroup cg{
-      new_configuration_contactgroup("test_cg", "test_contact")};
-#else
   configuration::Contactgroup cg;
   configuration::contactgroup_helper cg_hlp(&cg);
   fill_pb_configuration_contactgroup(&cg_hlp, "test_cg", "test_contact");
-#endif
   cg_aply.add_object(cg);
-#ifdef LEGACY_CONF
-  cg_aply.expand_objects(*config);
-#else
   cg_aply.expand_objects(pb_config);
-#endif
   cg_aply.resolve_object(cg, err);
 
   configuration::applier::hostescalation he_aply;
-#ifdef LEGACY_CONF
-  configuration::hostescalation he{
-      new_configuration_hostescalation("test_host", "test_cg", 1, 0, 0)};
-#else
   configuration::Hostescalation he{
       new_pb_configuration_hostescalation("test_host", "test_cg", 1, 0, 0)};
-#endif
   he_aply.add_object(he);
-#ifdef LEGACY_CONF
-  he_aply.expand_objects(*config);
-#else
   he_aply.expand_objects(pb_config);
-#endif
   he_aply.resolve_object(he, err);
 
   int now{50000};
@@ -1160,51 +1023,25 @@ TEST_F(HostNotification, HostEscalationOneTimeNotifInter0) {
 TEST_F(HostNotification, HostEscalationRetention) {
   error_cnt err;
   configuration::applier::contact ct_aply;
-#ifdef LEGACY_CONF
-  configuration::contact ctct{new_configuration_contact("test_contact", false)};
-#else
   configuration::Contact ctct{
       new_pb_configuration_contact("test_contact", false)};
-#endif
   ct_aply.add_object(ctct);
-#ifdef LEGACY_CONF
-  ct_aply.expand_objects(*config);
-#else
   ct_aply.expand_objects(pb_config);
-#endif
   ct_aply.resolve_object(ctct, err);
 
   configuration::applier::contactgroup cg_aply;
-#ifdef LEGACY_CONF
-  configuration::contactgroup cg{
-      new_configuration_contactgroup("test_cg", "test_contact")};
-#else
   configuration::Contactgroup cg;
   configuration::contactgroup_helper cg_hlp(&cg);
   fill_pb_configuration_contactgroup(&cg_hlp, "test_cg", "test_contact");
-#endif
   cg_aply.add_object(cg);
-#ifdef LEGACY_CONF
-  cg_aply.expand_objects(*config);
-#else
   cg_aply.expand_objects(pb_config);
-#endif
   cg_aply.resolve_object(cg, err);
 
   configuration::applier::hostescalation he_aply;
-#ifdef LEGACY_CONF
-  configuration::hostescalation he{
-      new_configuration_hostescalation("test_host", "test_cg", 1, 0, 0)};
-#else
   configuration::Hostescalation he{
       new_pb_configuration_hostescalation("test_host", "test_cg", 1, 0, 0)};
-#endif
   he_aply.add_object(he);
-#ifdef LEGACY_CONF
-  he_aply.expand_objects(*config);
-#else
   he_aply.expand_objects(pb_config);
-#endif
   he_aply.resolve_object(he, err);
 
   int now{50000};
