@@ -28,10 +28,6 @@
 #include "com/centreon/engine/configuration/applier/contact.hh"
 #include "com/centreon/engine/configuration/applier/host.hh"
 #include "com/centreon/engine/configuration/applier/service.hh"
-#ifdef LEGACY_CONF
-#include "common/engine_legacy_conf/host.hh"
-#include "common/engine_legacy_conf/service.hh"
-#endif
 
 #include "opentelemetry/proto/collector/metrics/v1/metrics_service.pb.h"
 #include "opentelemetry/proto/common/v1/common.pb.h"
@@ -542,10 +538,9 @@ TEST_F(otl_converter_test, nagios_telegraf) {
   metric_request_ptr request =
       std::make_shared< ::opentelemetry::proto::collector::metrics::v1::
                             ExportMetricsServiceRequest>();
-  auto status = ::google::protobuf::util::JsonStringToMessage(telegraf_example,
-                                                              request.get());
+  (void)::google::protobuf::util::JsonStringToMessage(telegraf_example,
+                                                      request.get());
 
-  ASSERT_TRUE(status.ok()) << status.ToString();
   metric_to_datapoints received;
   otl_data_point::extract_data_points(
       request, [&](const otl_data_point& data_pt) {
@@ -573,7 +568,7 @@ TEST_F(otl_converter_test, nagios_telegraf_le_ge) {
   boost::algorithm::replace_all(example, "check_icmp_critical_lt",
                                 "check_icmp_critical_le");
 
-  ::google::protobuf::util::JsonStringToMessage(example, request.get());
+  (void)::google::protobuf::util::JsonStringToMessage(example, request.get());
 
   metric_to_datapoints received;
   otl_data_point::extract_data_points(
@@ -600,7 +595,7 @@ TEST_F(otl_converter_test, nagios_telegraf_max) {
   std::string example = telegraf_example;
   boost::algorithm::replace_all(example, "check_icmp_min", "check_icmp_max");
 
-  ::google::protobuf::util::JsonStringToMessage(example, request.get());
+  (void)::google::protobuf::util::JsonStringToMessage(example, request.get());
 
   metric_to_datapoints received;
   otl_data_point::extract_data_points(
